@@ -17,13 +17,13 @@ from urllib3.util.retry import Retry
 from tqdm import tqdm
 import ntpath
 
-__version__ = "1.2.7"
+__version__ = "1.2.8"
 CONFIG_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                            ".canvassyncer.json")
 MAX_DOWNLOAD_COUNT = 8
 _sentinel = object()
 
-# print = partial(print, flush=True)
+print = partial(print, flush=True)
 
 
 class MultithreadDownloader:
@@ -264,6 +264,7 @@ class CanvasSyncer:
                 if isinstance(courses, dict) and courses.get('errors'):
                     errMsg = courses['errors'][0].get('message',
                                                       'unknown error.')
+                    print(f"\nError: {errMsg}")
                     exit(1)
                 if not courses:
                     break
